@@ -32,8 +32,8 @@ class Messages_theme_Manager(CommonTreeGridManager):
     def createFromRequest(self, request):
         from tracker.models.messages_theme_users_access import MessagesThemeUsersAccess
 
-        user_id = request.user.id
         _request = DSRequest(request=request)
+        user_id = _request.user.id
         data = _request.get_data()
         _data = data.copy()
         delAttr(_data, 'isFolder')
